@@ -15,7 +15,7 @@ def op_DECL(state: State, name: str, value: str) -> None:
     state.require(
         is_valid_name(name), 
         f'{name} is not a correct name.', 
-        f'Names can only contain alphanumeric signs, underscores and cannot be: {print_invalid_names()}.'
+        f'Names can only contain alphanumeric characters, underscores and cannot be: {print_invalid_names()}.'
     )
     state.require(not state.last_agent.param_exists(name), f'{name} is already defined in current agent.')
     state.require(
